summaryrefslogtreecommitdiff
path: root/src/shell-action-modes.h
diff options
context:
space:
mode:
authorFlorian Müllner <fmuellner@gnome.org>2015-02-23 20:07:04 +0100
committerFlorian Müllner <fmuellner@gnome.org>2015-02-23 21:39:22 +0100
commitc79d24b60e773262091023feb6ee1b3deef1c471 (patch)
tree286fc1813831bb2e973888ea7289bb4fe486819d /src/shell-action-modes.h
parent509464fd61cd5eb4ba7e0a3df96b1562cd31de32 (diff)
downloadgnome-shell-c79d24b60e773262091023feb6ee1b3deef1c471.tar.gz
popupMenu: Use TOPBAR_POPUP action mode for all menus
When it comes to keybindings or gestures, there's not really a good reason why popups associated with the top bar should behave differently from any other shell menus. Just set the action mode generically for all menus, so actions like screenshots or media-keys start working with menus like the background- or app launcher context menus. https://bugzilla.gnome.org/show_bug.cgi?id=745039
Diffstat (limited to 'src/shell-action-modes.h')
-rw-r--r--src/shell-action-modes.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/src/shell-action-modes.h b/src/shell-action-modes.h
index cff1d12ac..bf21d341c 100644
--- a/src/shell-action-modes.h
+++ b/src/shell-action-modes.h
@@ -15,8 +15,7 @@
* @SHELL_ACTION_MODE_SYSTEM_MODAL: allow action when a system modal
* dialog (e.g. authentification or session dialogs) is open
* @SHELL_ACTION_MODE_LOOKING_GLASS: allow action in looking glass
* @SHELL_ACTION_MODE_TOPBAR_POPUP: allow action while a top bar menu
* is open
* @SHELL_ACTION_MODE_ALL: always allow action
*
* Controls in which GNOME Shell states an action (like keybindings and gestures)
@@ -32,7 +31,7 @@ typedef enum {
SHELL_ACTION_MODE_MESSAGE_TRAY = 1 << 5,
SHELL_ACTION_MODE_SYSTEM_MODAL = 1 << 6,
SHELL_ACTION_MODE_LOOKING_GLASS = 1 << 7,
- SHELL_ACTION_MODE_TOPBAR_POPUP = 1 << 8,
+ SHELL_ACTION_MODE_POPUP = 1 << 8,
SHELL_ACTION_MODE_ALL = ~0,
} ShellActionMode;
@@ -15,8 +15,7 @@
* dialog (e.g. authentification or session dialogs) is open
* @SHELL_ACTION_MODE_LOOKING_GLASS: allow action in looking glass
- * @SHELL_ACTION_MODE_TOPBAR_POPUP: allow action while a top bar menu
- * is open
+ * @SHELL_ACTION_MODE_POPUP: allow action while a shell menu is open
* @SHELL_ACTION_MODE_ALL: always allow action
*